@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __GPK_CHECK_UPDATE_H
@@ -50,6 +50,8 @@ typedef struct
 
 GType		 gpk_check_update_get_type		  	(void);
 GpkCheckUpdate	*gpk_check_update_new				(void);
+void		 gpk_check_update_set_status_icon		(GpkCheckUpdate	*check_update,
+								 GtkStatusIcon	*status_icon);
 
 G_END_DECLS
 
